@@ -21,7 +21,7 @@ setClass("AbstractMassObject",
     representation=representation(mass="vector", intensity="vector",
         metaData="list", .cache="environment"),
     prototype=prototype(mass=vector(mode="numeric"), 
-        peaks=vector(mode="numeric"), metaData=list()),
+        intensity=vector(mode="numeric"), metaData=list()),
     contains="VIRTUAL");
 
 ## represent a spectrum
