@@ -21,13 +21,19 @@ setMethod(f="plot",
     signature=signature(x="AbstractMassObject", y="missing"),
     definition=function(x, col="black", xlab="mass", ylab="intensity",
         type=ifelse(isMassPeaks(x), "h", "l"),
-        xlim=c(ifelse(length(x@mass)>0, min(x@mass, na.rm=TRUE), 0),
-               ifelse(length(x@mass)>0, max(x@mass, na.rm=TRUE), 1)),
+        xlim=c(ifelse(length(x@mass) > 0, min(x@mass, na.rm=TRUE), 0),
+               ifelse(length(x@mass) > 0, max(x@mass, na.rm=TRUE), 1)),
         ylim=c(0, ifelse(length(x@intensity>0), 
                          max(x@intensity, na.rm=TRUE), 1)),
         main=x@metaData$name, sub=x@metaData$file, cex.sub=0.75, 
-        col.sub="#808080", 
-        abline.col="#808080", ...) {
+        col.sub="#808080", abline.col="#808080", ...) {
+
+    if (all(sub == x@metaData$file) && length(x@metaData$file) > 1) {
+        sub <- paste("merged ", ifelse(isMassSpectrum(x), "spectrum", "peaks"),
+                     " composed of ", length(x@metaData$file), " ",
+                     ifelse(isMassSpectrum(x), "MassSpectrum", "MassPeaks"), 
+                     " objects", sep="");
+    }
 
     plot(x=x@mass, y=x@intensity, col=col, type=type, xlab=xlab, ylab=ylab, 
         xlim=xlim, ylim=ylim, main=main, sub=sub, cex.sub=cex.sub, 
